@@ -498,6 +498,29 @@ pub mod macros {
         };};
     }
 
+    /// vec_element_position_all!() used to find element position and collect into Vec<usize>
+    /// ```rust
+    ///let v1 = vec_element_position_all!(vec![1, 2, 5, 3, 6, 2, 2], 2);
+    ///assert_eq!(v1, vec![1, 5, 6]);
+    /// ```
+    #[macro_export]
+    macro_rules! vec_element_position_all {
+        ($vec:expr,$element:expr) => {{
+            let mut vec = $vec.clone();
+            fn position<T: Copy + PartialOrd<T>>(vec: Vec<T>, target: &T) -> Vec<usize> {
+                let mut v1 = vec.clone();
+                let mut re = vec![];
+                for i in 0..v1.len() {
+                    if v1[i] == *target {
+                        re.push(i);
+                    }
+                }
+                re
+            }
+            position(vec, &$element)
+        };};
+    }
+
     pub fn run() {}
 }
 
